import _objectWithoutPropertiesLoose from "reshow-runtime/es/helpers/objectWithoutPropertiesLoose";
import _objectSpread from "reshow-runtime/es/helpers/objectSpread2";
import _inheritsLoose from "reshow-runtime/es/helpers/inheritsLoose";
import _defineProperty from "reshow-runtime/es/helpers/defineProperty";
import React, { Component, isValidElement } from 'react';
import { connect } from 'reshow-flux';
import { build, SemanticUI } from 'react-atomic-molecule';
import scrollStore from '../../src/stores/scrollStore';
import fastScrollStore from '../../src/stores/fastScrollStore';

var ScrollReceiver = /*#__PURE__*/function (_Component) {
  _inheritsLoose(ScrollReceiver, _Component);

  function ScrollReceiver() {
    return _Component.apply(this, arguments) || this;
  }

  ScrollReceiver.getStores = function getStores(props) {
    return props.noDelay ? [fastScrollStore] : [scrollStore];
  };

  ScrollReceiver.calculateState = function calculateState(prevState, props) {
    var noDelay = props.noDelay,
        targetId = props.targetId,
        scrollMargin = props.scrollMargin;
    var store = noDelay ? fastScrollStore : scrollStore;
    var state = store.getState();
    var isShown = prevState && prevState.isShown || false;
    var pos = store.getOffset(targetId, store.storeName) || {};
    var scrollInfo = store.getMap('scroll');
    var scrollTop = scrollInfo.top;

    if (pos.isOnScreen) {
      isShown = true;
    }

    var active = 'undefined' !== typeof targetId && targetId === state.get('m' + scrollMargin);

    if (!isNaN(scrollMargin)) {
      store.addMargin(scrollMargin);
    }

    return _objectSpread(_objectSpread({}, pos), {}, {
      active: active,
      scrollTop: scrollTop,
      scrollInfo: scrollInfo,
      isShown: isShown
    });
  };

  var _proto = ScrollReceiver.prototype;

  _proto.render = function render() {
    var _this$props = this.props,
        atom = _this$props.atom,
        container = _this$props.container,
        scrollMargin = _this$props.scrollMargin,
        targetId = _this$props.targetId,
        isScrollReceiver = _this$props.isScrollReceiver,
        noDelay = _this$props.noDelay,
        children = _this$props.children,
        resetProps = _objectWithoutPropertiesLoose(_this$props, ["atom", "container", "scrollMargin", "targetId", "isScrollReceiver", "noDelay", "children"]);

    if (!container) {
      return /*#__PURE__*/React.createElement(SemanticUI, resetProps, children);
    }

    var targetInfo = _objectSpread(_objectSpread({}, this.state), {}, {
      targetId: targetId
    });

    var thisChildren = children;

    if (!thisChildren && /*#__PURE__*/isValidElement(container)) {
      thisChildren = container.props.children;
    }

    return build(container)(_objectSpread(_objectSpread({}, resetProps), {}, {
      targetInfo: targetInfo
    }), thisChildren);
  };

  return ScrollReceiver;
}(Component);

_defineProperty(ScrollReceiver, "defaultProps", {
  scrollMargin: 'default',
  isScrollReceiver: true,
  noDelay: false
});

export default connect(ScrollReceiver, {
  withProps: true
});